@@ -7,7 +7,7 @@
  */
 
 #include "wvdialer.h"
-#include "wvver.h"
+#include "version.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -24,13 +24,13 @@
 // N_() is defined here just for internationalization.
 #define N_(String)  String
 
-static char *	init_responses[] = {
+static const char *	init_responses[] = {
 	"ok",
 	"error",
 	NULL
 };
 
-static char *	dial_responses[] = {
+static const char *	dial_responses[] = {
 	"connect",
 	"no carrier",
 	"no dialtone",
@@ -43,7 +43,7 @@ static char *	dial_responses[] = {
 	NULL
 };
 
-static char *	prompt_strings[] = {
+static const char *	prompt_strings[] = {
 	"}!}",
 	"!}!",
 	NULL
@@ -641,11 +641,12 @@ void WvDialer::load_options()
         { "Idle Seconds",    NULL, &options.idle_seconds,  "", 0            },
         { "ISDN",            NULL, &options.isdn,          "", false        },
         { "Ask Password",    NULL, &options.ask_password,  "", false        },
+        { "Dial Timeout",    NULL, &options.dial_timeout,  "", 60           },
 
     	{ NULL,		     NULL, NULL,                   "", 0            }
     };
 
-    char *	d = "Dialer Defaults";
+    const char * d = "Dialer Defaults";
 
     for( int i=0; opts[i].name != NULL; i++ ) 
     {
@@ -783,7 +784,7 @@ bool WvDialer::init_modem()
 			    err( "Bad init string.\n" );
 			    return( false );
 		    }
-		    goto end_outer;
+		    break;
 		case 1:
 		    err( "Bad init string.\n" );
 		    goto end_outer;
@@ -908,7 +909,7 @@ void WvDialer::async_dial()
     switch( received ) 
     {
     case -1:	// nothing -- return control.
-	if( time( NULL ) - last_rx  >= 60 ) 
+	if( time( NULL ) - last_rx  >= options.dial_timeout ) 
 	{
 	    log( WvLog::Warning, "Timed out while dialing.  Trying again.\n" );
 	    stat = PreDial1;
@@ -1338,7 +1339,7 @@ static void strip_parity( char * buf, size_t size )
 }
 
 
-int WvDialer::wait_for_modem( char * 	strs[], 
+int WvDialer::wait_for_modem( const char * strs[], 
 			      int	timeout, 
 			      bool	neednewline,
 			      bool 	verbose )
@@ -1421,7 +1422,7 @@ int WvDialer::wait_for_modem( char * 	strs[],
     return( result ); // -1 == timeout
 }
 
-int WvDialer::async_wait_for_modem( char * strs[], bool neednl, bool verbose )
+int WvDialer::async_wait_for_modem( const char * strs[], bool neednl, bool verbose )
 /****************************************************************************/
 {
     return( wait_for_modem( strs, 10, neednl, verbose ) );
