@@ -20,7 +20,7 @@ bool     default_asyncmap = false;
 
 // startup at atz atq0 atv1 ate1 ats0 carrier dtr fastdial
 // baudstep reinit done
-static char *commands[WvModemScan::NUM_STAGES] = {
+static const char *commands[WvModemScan::NUM_STAGES] = {
     NULL, "Q0 V1 E1", "Z", "S0=0",
     "&C1", "&D2", "+FCLASS=0", NULL,
     NULL, "", NULL
@@ -495,16 +495,15 @@ static int fileselect(const struct dirent *e)
 	// (no internal ISDN support)   || !strncmp(e->d_name, "ttyI", 4);
 }
 
-
 #if defined(__GLIBC__) && __GLIBC_PREREQ(2, 10)
-static int filesort(const struct dirent **e1, const struct dirent **e2)
+static int filesort(const dirent **e1, const dirent **e2)
 #else
 static int filesort(const void *_e1, const void *_e2)
 #endif
 {
 #if !(defined(__GLIBC__) && __GLIBC_PREREQ(2, 10))
-     dirent const * const *e1 = (dirent const * const *)_e1;
-     dirent const * const *e2 = (dirent const * const *)_e2;
+    dirent const * const *e1 = (dirent const * const *)_e1;
+    dirent const * const *e2 = (dirent const * const *)_e2;
 #endif
     const char *p1, *p2;
     int diff;
